@@ -24,7 +24,7 @@
 // Copyright (C) 2015, 2018 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2015 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
-// Copyright (C) 2021 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2021, 2022 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -188,16 +188,14 @@ public:
     };
 
     // Build a GfxFont object.
-    static GfxFont *makeFont(XRef *xref, const char *tagA, Ref idA, Dict *fontDict);
+    static std::unique_ptr<GfxFont> makeFont(XRef *xref, const char *tagA, Ref idA, Dict *fontDict);
 
     GfxFont(const GfxFont &) = delete;
     GfxFont &operator=(const GfxFont &other) = delete;
+    virtual ~GfxFont();
 
     bool isOk() const { return ok; }
 
-    void incRefCnt();
-    void decRefCnt();
-
     // Get font tag.
     const std::string &getTag() const { return tag; }
 
@@ -218,7 +216,7 @@ public:
 
     // Get the original font name (ignornig any munging that might have
     // been done to map to a canonical Base-14 font name).
-    const GooString *getName() const { return name; }
+    const std::optional<std::string> &getName() const { return name; }
 
     bool isSubset() const;
 
@@ -274,17 +272,14 @@ public:
     double getDescent() const { return descent; }
 
     // Return the writing mode (0=horizontal, 1=vertical).
-    virtual int getWMode() { return 0; }
+    virtual int getWMode() const { return 0; }
 
     // Locate the font file for this font.  If <ps> is not null, includes PS
     // printer-resident fonts.  Returns std::optional without a value on failure.
     std::optional<GfxFontLoc> locateFont(XRef *xref, PSOutputDev *ps);
 
-    // Locate a Base-14 font file for a specified font name.
-    static std::optional<GfxFontLoc> locateBase14Font(const GooString *base14Name);
-
     // Read an external or embedded font file into a buffer.
-    char *readEmbFontFile(XRef *xref, int *len);
+    std::optional<std::vector<unsigned char>> readEmbFontFile(XRef *xref);
 
     // Get the next char from a string <s> of <len> bytes, returning the
     // char <code>, its Unicode mapping <u>, its displacement vector
@@ -306,9 +301,7 @@ public:
     static const char *getAlternateName(const char *name);
 
 protected:
-    GfxFont(const char *tagA, Ref idA, const GooString *nameA, GfxFontType typeA, Ref embFontIDA);
-
-    virtual ~GfxFont();
+    GfxFont(const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA);
 
     static GfxFontType getFontType(XRef *xref, Dict *fontDict, Ref *embID);
     void readFontDescriptor(XRef *xref, Dict *fontDict);
@@ -317,7 +310,7 @@ protected:
 
     const std::string tag; // PDF font tag
     const Ref id; // reference (used as unique ID)
-    const GooString *name; // font name
+    std::optional<std::string> name; // font name
     GooString *family; // font family
     Stretch stretch; // font stretch
     Weight weight; // font weight
@@ -330,7 +323,6 @@ protected:
     double missingWidth; // "default" width
     double ascent; // max height above baseline
     double descent; // max depth below baseline
-    int refCnt;
     bool ok;
     bool hasToUnicode;
     std::string encodingName;
@@ -343,7 +335,7 @@ protected:
 class POPPLER_PRIVATE_EXPORT Gfx8BitFont : public GfxFont
 {
 public:
-    Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
+    Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
 
     int getNextChar(const char *s, int len, CharCode *code, Unicode const **u, int *uLen, double *dx, double *dy, double *ox, double *oy) const override;
 
@@ -403,14 +395,14 @@ private:
 class POPPLER_PRIVATE_EXPORT GfxCIDFont : public GfxFont
 {
 public:
-    GfxCIDFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
+    GfxCIDFont(XRef *xref, const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
 
     bool isCIDFont() const override { return true; }
 
     int getNextChar(const char *s, int len, CharCode *code, Unicode const **u, int *uLen, double *dx, double *dy, double *ox, double *oy) const override;
 
     // Return the writing mode (0=horizontal, 1=vertical).
-    int getWMode() override;
+    int getWMode() const override;
 
     // Return the Unicode map.
     const CharCodeToUnicode *getToUnicode() const override;
@@ -421,7 +413,7 @@ public:
     // Return the CID-to-GID mapping table.  These should only be called
     // if type is fontCIDType2.
     int *getCIDToGID() const { return cidToGID; }
-    int getCIDToGIDLen() const { return cidToGIDLen; }
+    unsigned int getCIDToGIDLen() const { return cidToGIDLen; }
 
     int *getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen);
 
@@ -441,7 +433,7 @@ private:
     GfxFontCIDWidths widths; // character widths
     int *cidToGID; // CID --> GID mapping (for embedded
                    //   TrueType fonts)
-    int cidToGIDLen;
+    unsigned int cidToGIDLen;
 };
 
 //------------------------------------------------------------------------
@@ -454,25 +446,21 @@ public:
     // Build the font dictionary, given the PDF font dictionary.
     GfxFontDict(XRef *xref, Ref *fontDictRef, Dict *fontDict);
 
-    // Destructor.
-    ~GfxFontDict();
-
     GfxFontDict(const GfxFontDict &) = delete;
     GfxFontDict &operator=(const GfxFontDict &) = delete;
 
     // Get the specified font.
-    GfxFont *lookup(const char *tag) const;
+    std::shared_ptr<GfxFont> lookup(const char *tag) const;
 
     // Iterative access.
-    int getNumFonts() const { return numFonts; }
-    GfxFont *getFont(int i) const { return fonts[i]; }
+    int getNumFonts() const { return fonts.size(); }
+    const std::shared_ptr<GfxFont> &getFont(int i) const { return fonts[i]; }
 
 private:
     int hashFontObject(Object *obj);
     void hashFontObject1(const Object *obj, FNVHash *h);
 
-    GfxFont **fonts; // list of fonts
-    int numFonts; // number of fonts
+    std::vector<std::shared_ptr<GfxFont>> fonts;
 };
 
 #endif
