@@ -3,7 +3,7 @@
 // This file is under the GPLv2 or later license
 //
 // Copyright (C) 2005-2006 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005, 2018, 2019 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2018-2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
@@ -25,36 +25,39 @@
 
 #include "Object.h"
 
-class PageLabelInfo {
+class PageLabelInfo
+{
 public:
-  PageLabelInfo(Object *tree, int numPages);
+    PageLabelInfo(Object *tree, int numPages);
 
-  PageLabelInfo(const PageLabelInfo &) = delete;
-  PageLabelInfo& operator=(const PageLabelInfo &) = delete;
+    PageLabelInfo(const PageLabelInfo &) = delete;
+    PageLabelInfo &operator=(const PageLabelInfo &) = delete;
 
-  bool labelToIndex(GooString *label, int *index) const;
-  bool indexToLabel(int index, GooString *label) const;
+    bool labelToIndex(GooString *label, int *index) const;
+    bool indexToLabel(int index, GooString *label) const;
 
 private:
-  void parse(Object *tree);
+    void parse(const Object *tree, std::set<int> &parsedRefs);
 
 private:
-  struct Interval {
-    Interval(Object *dict, int baseA);
+    struct Interval
+    {
+        Interval(Object *dict, int baseA);
 
-    std::string prefix;
-    enum NumberStyle {
-      None,
-      Arabic,
-      LowercaseRoman,
-      UppercaseRoman,
-      UppercaseLatin,
-      LowercaseLatin
-    } style;
-    int first, base, length;
-  };
+        std::string prefix;
+        enum NumberStyle
+        {
+            None,
+            Arabic,
+            LowercaseRoman,
+            UppercaseRoman,
+            UppercaseLatin,
+            LowercaseLatin
+        } style;
+        int first, base, length;
+    };
 
-  std::vector<Interval> intervals;
+    std::vector<Interval> intervals;
 };
 
 #endif
