@@ -15,6 +15,7 @@
  * Copyright (C) 2020 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
  * Copyright (C) 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
  * Copyright (C) 2021 Theofilos Intzoglou <int.teo@gmail.com>
+ * Copyright (C) 2022 Alexander Sulfrian <asulfrian@zedat.fu-berlin.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -193,7 +194,14 @@ void FormField::setReadOnly(bool value)
 
 bool FormField::isVisible() const
 {
-    return !(m_formData->fm->getWidgetAnnotation()->getFlags() & Annot::flagHidden);
+    const unsigned int flags = m_formData->fm->getWidgetAnnotation()->getFlags();
+    if (flags & Annot::flagHidden) {
+        return false;
+    }
+    if (flags & Annot::flagNoView) {
+        return false;
+    }
+    return true;
 }
 
 void FormField::setVisible(bool value)
@@ -201,6 +209,7 @@ void FormField::setVisible(bool value)
     unsigned int flags = m_formData->fm->getWidgetAnnotation()->getFlags();
     if (value) {
         flags &= ~Annot::flagHidden;
+        flags &= ~Annot::flagNoView;
     } else {
         flags |= Annot::flagHidden;
     }
@@ -1102,8 +1111,9 @@ FormFieldSignature::SigningResult FormFieldSignature::sign(const QString &output
     const auto gSignatureText = std::unique_ptr<GooString>(QStringToUnicodeGooString(data.signatureText()));
     const auto gSignatureLeftText = std::unique_ptr<GooString>(QStringToUnicodeGooString(data.signatureLeftText()));
 
-    const bool success = fws->signDocumentWithAppearance(outputFileName.toUtf8().constData(), data.certNickname().toUtf8().constData(), "SHA256", data.password().toUtf8().constData(), reason.get(), location.get(), ownerPwd, userPwd,
-                                                         *gSignatureText, *gSignatureLeftText, data.fontSize(), convertQColor(data.fontColor()), data.borderWidth(), convertQColor(data.borderColor()), convertQColor(data.backgroundColor()));
+    const bool success =
+            fws->signDocumentWithAppearance(outputFileName.toUtf8().constData(), data.certNickname().toUtf8().constData(), "SHA256", data.password().toUtf8().constData(), reason.get(), location.get(), ownerPwd, userPwd, *gSignatureText,
+                                            *gSignatureLeftText, data.fontSize(), data.leftFontSize(), convertQColor(data.fontColor()), data.borderWidth(), convertQColor(data.borderColor()), convertQColor(data.backgroundColor()));
 
     return success ? SigningSuccess : GenericSigningError;
 }
