@@ -143,7 +143,10 @@ public:
 
     void addTocChildren(QDomDocument *docSyn, QDomNode *parent, const std::vector<::OutlineItem *> *items);
 
-    void setPaperColor(const QColor &color) { paperColor = color; }
+    void setPaperColor(const QColor &color)
+    {
+        paperColor = color;
+    }
 
     void fillMembers()
     {
@@ -197,12 +200,15 @@ public:
 
     explicit FontInfoData(::FontInfo *fi)
     {
-        if (fi->getName())
+        if (fi->getName()) {
             fontName = fi->getName()->c_str();
-        if (fi->getFile())
+        }
+        if (fi->getFile()) {
             fontFile = fi->getFile()->c_str();
-        if (fi->getSubstituteName())
+        }
+        if (fi->getSubstituteName()) {
             fontSubstituteName = fi->getSubstituteName()->c_str();
+        }
         isEmbedded = fi->getEmbedded();
         isSubset = fi->getSubset();
         type = (Poppler::FontInfo::Type)fi->getType();
