@@ -35,9 +35,8 @@ void TestAnnotations::checkQColorPrecision()
     bool precisionOk = true;
     for (int i = std::numeric_limits<uint16_t>::min(); i <= std::numeric_limits<uint16_t>::max(); i++) {
         double normalized = static_cast<uint16_t>(i) / static_cast<double>(std::numeric_limits<uint16_t>::max());
-        GooString *serialized = GooString::format("{0:.5f}", normalized);
+        const std::unique_ptr<GooString> serialized = GooString::format("{0:.5f}", normalized);
         double deserialized = gatof(serialized->c_str());
-        delete serialized;
         uint16_t denormalized = std::round(deserialized * std::numeric_limits<uint16_t>::max());
         if (static_cast<uint16_t>(i) != denormalized) {
             precisionOk = false;
@@ -98,8 +97,9 @@ void TestAnnotations::checkFontSizeAndColor()
             QCOMPARE(textAnnot->textFont().pointSize(), testFont.pointSize());
             QCOMPARE(static_cast<int>(textAnnot->textColor().spec()), static_cast<int>(color.spec()));
             QCOMPARE(textAnnot->textColor(), color);
-            if (annot != annots.constEnd())
+            if (annot != annots.constEnd()) {
                 ++annot;
+            }
         }
         qDeleteAll(annots);
     }
